@@ -57,9 +57,16 @@ getShortNames = function(.self, raw_filenames, max_length = 10, ms_runs = NULL)
     Returns a vector of the same length."
   #rf <<- raw_filenames
   #raw_filenames = rf
-
+  
   if (!is.null(ms_runs) && length(ms_runs) != length(raw_filenames)) stop("raw_filenames and ms_runs do not have the same length!")
   
+  ## for MQ-DIA data, the summary.txt is empty, thus we may receive an empty list here.
+  ## --> do nothing and wait for the next .txt file which has proper names
+  if (length(raw_filenames) == 0) {
+    warning("Empty raw file list in .txt file. Skipping mapping for now.")
+    return (list())
+  }
+  
   cat(paste0("Adding fc.raw.file column ..."))
   ## if there is no mapping, or if its incomplete (outdated mapping file)
   has_mapping = (nrow(.self$raw_file_mapping) != 0)
@@ -209,8 +216,8 @@ plotNameMapping = function(.self)
     mq_mapping.long2$hpos[mq_mapping.long2$variable==xpos[1]] = 1
     mq_mapping.long2$hpos[mq_mapping.long2$variable==xpos[2]] = 0
     
-    mqmap_pl = ggplot(mq_mapping.long2, aes_string(x = "variable", y = "ypos"))  +
-      geom_text(aes_string(label="value"), color = mq_mapping.long2$col, hjust=mq_mapping.long2$hpos, size=mq_mapping.long2$size) +
+    mqmap_pl = ggplot(mq_mapping.long2, aes(x = .data$variable, y = .data$ypos))  +
+      geom_text(aes(label = .data$value), color = mq_mapping.long2$col, hjust = mq_mapping.long2$hpos, size = mq_mapping.long2$size) +
       coord_cartesian(xlim=c(0,20)) +
       theme_bw() +
       theme(plot.margin = grid::unit(c(1,1,1,1), "cm"), line = element_blank(), 
