@@ -6,12 +6,20 @@
 #' @param do_plot            Show PCA plot? if ==2, then shows correlations plot as well
 #' @param connect_line_order Connect points by lines, the order is given by this vector.
 #'                           Default: NA (no lines)
-#' @param gg_layer           More parameters added to a ggplot object (ggplot(x) + gg_layer)                 
+#' @param gg_layer           More parameters added to a ggplot object (ggplot(x) + gg_layer)
 
 #' @return [invisible] Named list with "PCA": The PCA object as returned by \code{\link[stats]{prcomp}}, access $x for PC values
 #'                                 and "plots": list of plot objects (one or two)
 #' 
 #' @import ggplot2
+#' 
+#' @examples
+#' n = 5
+#' m = 10
+#' data = matrix(runif(n * m), nrow = n, ncol = m)
+#' rownames(data) = 1:n
+#' getPCA(data, connect_line_order = 1:n, gg_layer = ggplot2::ggtitle("test"))
+#' 
 #' @export
 #' 
 getPCA = function(data, do_plot = TRUE, connect_line_order = NA, gg_layer)
@@ -45,13 +53,13 @@ getPCA = function(data, do_plot = TRUE, connect_line_order = NA, gg_layer)
     var_PC1 = round(pc$sdev[1]^2 / sum(pc$sdev^2) * 100)
     var_PC2 = round(pc$sdev[2]^2 / sum(pc$sdev^2) * 100)
     
-    pl = ggplot(data=scores, aes_string(x = "PC1", y = "PC2"));
-    if (show.Line) pl = pl + geom_path(aes_string(x = "pathX", y = "pathY", color = "ord", alpha = "0.5"))
+    pl = ggplot(data=scores, aes(x = .data$PC1, y = .data$PC2));
+    if (show.Line) pl = pl + geom_path(aes(x = .data$pathX, y = .data$pathY, color = .data$ord), alpha = 0.5)
     pl = pl + scale_colour_gradient(low="red", high="darkgreen")
     pl = pl + 
               gg_layer + 
-              geom_point(aes_string(colour = "ord"), size = 1) +
-              geom_text(aes_string(label = "class", colour = "ord", vjust = "1"), size = 3, angle=0) +
+              geom_point(aes(colour = .data$ord), size = 1) +
+              geom_text(aes(label = .data$class, colour = .data$ord, vjust = 1), size = 4, angle=0) +
               geom_hline(yintercept=0, colour="gray65") +
               #theme(panel.background=element_rect("black")) +
               geom_vline(xintercept=0, colour="gray65") +
@@ -65,7 +73,7 @@ getPCA = function(data, do_plot = TRUE, connect_line_order = NA, gg_layer)
   
   if (do_plot==2)
   {
-    circle <- function(center=c(0,0), npoints=100)
+    my_circle = function(center=c(0,0), npoints=100)
     {
       r = 1
       tt = seq(0, 2*pi, length=npoints)
@@ -73,7 +81,7 @@ getPCA = function(data, do_plot = TRUE, connect_line_order = NA, gg_layer)
       yy = center[1] + r * sin(tt)
       return(data.frame(x = xx, y = yy))
     }
-    corcir = seqinr::circle(c(0,0), npoints = 100)
+    corcir = my_circle(c(0,0), npoints = 100)
     # create data frame with correlations between variables and PCs
     correlations = as.data.frame(cor(data, pc$x))
     # data frame with arrows coordinates
@@ -83,9 +91,9 @@ getPCA = function(data, do_plot = TRUE, connect_line_order = NA, gg_layer)
     
     lpl[[2]] = 
       ggplot() +
-      geom_path(data = corcir, aes_string(x = "x", y = "y"), colour="gray65") +  ## open circles
-      geom_segment(data = arrows, aes_string(x = "x1", y = "y1", xend = "x2", yend = "y2"), colour="gray65") +
-      geom_text(data = correlations, aes_string(x  = "PC1", y = "PC2", label = "rownames(correlations)")) +
+      geom_path(data = corcir, aes(x = .data$x, y = .data$y), colour="gray65") +  ## open circles
+      geom_segment(data = arrows, aes(x = .data$x1, y = .data$y1, xend = .data$x2, yend = .data$y2), colour="gray65") +
+      geom_text(data = correlations, aes(x  = .data$PC1, y = .data$PC2, label = rownames(correlations))) +
       geom_hline(yintercept = 0, colour = "gray65") +
       geom_vline(xintercept = 0, colour = "gray65") +
       xlim(-1.1,1.1) + ylim(-1.1,1.1) +
